***STATE HIRING CREDITS***
*Neumark - Grijalva 2016
*Forthcoming ILRR
*Table 9

clear
set more off

global data "C:\Users\Diego\Documents\Documents\USFQ\Publications\JCHC\Replication\data\Quarterly"

cd $data
*This database already includes the cyclical indicator
use JCHCdatabase_quarterly.dta, clear

*Merge minimum wage data
merge 1:1 state year quarter using minwage.dta
drop _merge

*Merge Unemployment Insurance Data
merge 1:1 state year quarter using UIWeeks_quarterly.dta
drop _merge

*Merge QWI data
merge 1:1 state year quarter using QWI.dta
drop _merge

*Drop the District of Columbia
drop if state==11
*Drop Massachusetts (QWI has no available data)
drop if state==25

sort state year quarter

*Save results in a Matrix for easy saving
*The first row is the coefficient
*The second row is the standard error
matrix input linco = (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
gen k=1

*Same but for joint significance tests
*The first row is the coefficient
*The second row is the p-value
matrix input joint = (0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0)
gen j=1

*Convert credit counts to dummies for 1 = at least one credit, 0 = none
*Generate lags of this variable
foreach var of varlist qjc qaet qacf qar qans qrecp qnrecp qteu qtew qted qnte {
   replace `var' = 1 if `var'>1 & `var'~=.
   gen `var'1 = `var'[_n-1] if state[_n] == state[_n-1]
   gen `var'2 = `var'[_n-2] if state[_n] == state[_n-2]
   gen `var'3 = `var'[_n-3] if state[_n] == state[_n-3]
   gen `var'4 = `var'[_n-4] if state[_n] == state[_n-4]
   gen `var'5 = `var'[_n-5] if state[_n] == state[_n-5]
   
   *First Differences
   gen d`var' = `var' - `var'1
   gen d`var'1 = `var'1 - `var'2
   gen d`var'2 = `var'2 - `var'3
   gen d`var'3 = `var'3 - `var'4
   gen d`var'4 = `var'4 - `var'5
}

*Same thing but for qlpse, qblminwage, and weeks_euc
foreach var of varlist qblminwage weeks_euc qlpse403 {
   gen `var'1 = `var'[_n-1] if state[_n] == state[_n-1]
   gen `var'2 = `var'[_n-2] if state[_n] == state[_n-2]
   gen `var'3 = `var'[_n-3] if state[_n] == state[_n-3]
   gen `var'4 = `var'[_n-4] if state[_n] == state[_n-4]
   gen `var'5 = `var'[_n-5] if state[_n] == state[_n-5]

   *First Differences
   gen d`var' = `var' - `var'1
   gen d`var'1 = `var'1 - `var'2
   gen d`var'2 = `var'2 - `var'3
   gen d`var'3 = `var'3 - `var'4
   gen d`var'4 = `var'4 - `var'5
}

*Same thing but for ARRA
foreach var of varlist ltobnoDOL {
   quietly gen `var'1 = `var'[_n-1] if state[_n] == state[_n-1]
   quietly gen `var'2 = `var'[_n-2] if state[_n] == state[_n-2]
   quietly gen `var'3 = `var'[_n-3] if state[_n] == state[_n-3]
   quietly gen `var'4 = `var'[_n-4] if state[_n] == state[_n-4]
   quietly gen `var'5 = `var'[_n-5] if state[_n] == state[_n-5]
   quietly gen `var'6 = `var'[_n-6] if state[_n] == state[_n-6]
   quietly gen `var'7 = `var'[_n-7] if state[_n] == state[_n-7]
   quietly gen `var'8 = `var'[_n-8] if state[_n] == state[_n-8]
   quietly gen `var'9 = `var'[_n-9] if state[_n] == state[_n-9]
   quietly gen `var'10 = `var'[_n-10] if state[_n] == state[_n-10]
   quietly gen `var'11 = `var'[_n-11] if state[_n] == state[_n-11]
   quietly gen `var'12 = `var'[_n-12] if state[_n] == state[_n-12]
   quietly gen `var'13 = `var'[_n-13] if state[_n] == state[_n-13]
   
   *First Differences
   quietly gen d`var' = `var' - `var'1
   quietly gen d`var'1 = `var'1 - `var'2
   quietly gen d`var'2 = `var'2 - `var'3
   quietly gen d`var'3 = `var'3 - `var'4
   quietly gen d`var'4 = `var'4 - `var'5
   quietly gen d`var'5 = `var'5 - `var'6
   quietly gen d`var'6 = `var'6 - `var'7
   quietly gen d`var'7 = `var'7 - `var'8
   quietly gen d`var'8 = `var'8 - `var'9
   quietly gen d`var'9 = `var'9 - `var'10
   quietly gen d`var'10 = `var'10 - `var'11
   quietly gen d`var'11 = `var'11 - `var'12
   quietly gen d`var'12 = `var'12 - `var'13
}

*First Difference of log employment, lemp, lempend, lhira, lhirn, and lsep 
gen dqll = qll[_n] - qll[_n-1] if state[_n]==state[_n-1]
gen dlemp = lemp[_n] - lemp[_n-1] if state[_n]==state[_n-1]
gen dlhira = lhira[_n] - lhira[_n-1] if state[_n]==state[_n-1]

*Generating lags of the political variables
foreach var of varlist govparty_c {
quietly gen `var'1 = `var'[_n-1] if state[_n] == state[_n-1]

*Generating first differences of these variables
quietly gen d`var' = `var' - `var'1
}

*Selecting the proper years of data for the sample
drop if year <= 2006 | year == 2012

*INTERACIONS

*State dummies
sort state year quarter
egen statedum = group(state)
quietly tab statedum, generate (sdum)
drop statedum

*Quarter dummies
egen timedum = group(year quarter)
sort timedum
quietly tab timedum, generate(qdum)
drop timedum

*Calendar quarter dummies
sort state year quarter
egen quarterdum = group(quarter)
quietly tab quarterdum, generate(quarterdum)
drop quarterdum

*Interactions
foreach var1 of varlist sdum* {
foreach var2 of varlist quarterdum* {
gen int`var1'`var2' = `var1'*`var2'
}
}

foreach var of varlist sdum* {
gen int`var'qlpse403 = `var'*qlpse403
}

*First differences of interactions
foreach var of varlist qdum* intsdum*quarterdum* intsdum*qlpse403 {
quietly gen d`var' = `var'[_n] - `var'[_n-1] if state[_n] == state[_n-1]
}

*Interactions of housing variables
foreach var1 of varlist nqn*{
foreach var2 of varlist qdum* {
gen int`var1'`var2' = `var1'*`var2'
}
}

*Program to produce a matrix of linear tests
capture program drop linearcombos
program define linearcombos

lincom `1'
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1 + `1'2
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1 + `1'2 + `1'3
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

lincom `1' + `1'1 + `1'2 + `1'3 + `1'4
matrix linco[1,k] = r(estimate)
matrix linco[2,k] = r(se)
replace k=k+1

end

*Program for joint tests
capture program drop jointtests
program define jointtests

test `1' `1'1 `1'2 `1'3 `1'4 
matrix joint[1,j] = r(F)
matrix joint[2,j] = r(p)
replace j=j+1

end

sort state year quarter

***REGRESSIONS***

drop dintsdum1qlpse qdum1 qdum2 intsdum1quarterdum*

drop intnqn1qdum*
         
forvalues i=2(1)5{
forvalues j=1(1)4 {
drop intnqn`i'qdum`j'
}
}

drop intnqn2qdum5 intnqn3qdum5 intnqn4qdum5 intnqn5qdum5

global int dqlpse403* dqblminwage* dweeks_euc* dltobn* intsdum*quarterdum* qdum* dintsdum*qlpse403 intnqn*

global pol govparty_c

*Credit
reg dlhira dqjc* $int $pol, vce(cluster state)

linearcombos dqjc
jointtests dqjc

*Amount of credit
reg dlhira dqaet* dqacf* dqar* dqans* $int $pol, vce(cluster state)

linearcombos dqaet
jointtests dqaet
linearcombos dqacf
jointtests dqacf
linearcombos dqar
jointtests dqar
linearcombos dqans
jointtests dqans

*Recapture provisions
reg dlhira dqrecp* dqnrecp* $int $pol, vce(cluster state)

linearcombos dqrecp
jointtests dqrecp
linearcombos dqnrecp
jointtests dqnrecp

*Target by employee
reg dlhira dqteu* dqted* dqnte* $int $pol, vce(cluster state)

linearcombos dqteu
jointtests dqteu
linearcombos dqted
jointtests dqted
linearcombos dqnte
jointtests dqnte

***RESULTS***

matrix list linco
matrix lincot=linco'
matrix list joint
matrix jointt=joint'

putexcel set Table10, sheet(Results) modify
putexcel B2 = matrix(lincot)

putexcel set Table10, sheet(Jointtests) modify
putexcel B2 = matrix(jointt)
